{% extends "social/base/login_snippet.html" %}

{% block social %}
    <form method="post" action="{{'login'|route_url}}/facebook">

        <input name="csrf_token" type="hidden" value="{{ request.session.get_csrf_token() }}"/>

        <button class="btn btn-primary btn-block btn-lg btn-magic-login btn-login-facebook">
            <span class="btn-magic-login-inner">
              <i class="fa fa-facebook btn-magic-login-icon"></i>
              Continue with Facebook
            </span>
        </button>
    </form>
{% endblock social %}

