{% extends "email/base.html" %}

{% block content %}
<p style="text-align: center; margin: 25px auto">
    <a class="btn-primary" style="font-size: 120%" href="{{verify_link}}">Sign in to {{ site_name }}</a>
</p>

<p style="text-align: center">
    This is a sign in email sent from {{ site_name }}. Click the link above to continue signing in. This link can be used only once and it expires in {{ verify_minutes }} minutes.
</p>

{% endblock %}
