{% extends "site/base.html" %}

{% block description %}
  <title>Sign in to {{ site_name }}</title>
  <meta name="description" content="">
{% endblock %}

{% block extra_head %}
{# Include myapp package theme #}
<link rel="stylesheet" href="{{ 'websauna.magiclogin:static/magiclogin.css'|static_url }}">
{% endblock %}

{% block content %}

  <div class="magic-login-wrapper">
    <div class="row">
      <div class="col-md-12">

        <div id="{% block login_panel_id %}{% endblock %}" class="panel panel-default panel-magic-login">
          <div class="panel-heading">
            <div class="text-center">
              <img src="{{ 'websauna.magiclogin:static/logo.png'|static_url }}" alt="">
            </div>
          </div>

          <div class="panel-body">
            {% block login_content %}
            {% endblock %}
          </div>
        </div>
      </div>
    </div>
  </div>
{% endblock content %}

