.panel-magic-login {
  max-width: 600px;
  margin: 0 auto;
}

.panel-magic-login .panel-body {
  padding: 40px;
}

.magic-login-buttons {
  margin-top: 20px;
}

.magic-login-social-button-wrapper {
  margin: 20px 20px;
}

.btn-magic-login {
  text-align: left;
  transition: all 0.3s ease 0s;
}

.btn-magic-login .btn-magic-login-icon {
  width: 25px;
  height: 25px;
  text-align: center;
}

.btn-magic-login-inner {
  width: 240px;
  margin: 0 auto;
}

@media(max-width: 960px) {
  .btn-magic-login .btn-magic-login-icon {
    margin-left: 20px;
  }
}
@media(max-width: 768px) {
  .btn-magic-login-inner {
    font-size: 80%;
  }
}

.btn-login-facebook {
  /*color: #3b5998;
  border: 1px solid #3b5998;
  background: white;*/
  background: #3b5998;
  border: 1px solid #3b5998;
  color: white;
}

.btn-login-facebook:hover {
  background: #1d315b;
  border: 1px solid #1d315b;
}

.btn-login-google {
  color: #333;
  background: white;
}

.btn-login-google:hover {
  background: #ddd;
  border: 1px solid black;
  color: black;
}

.btn-login-twitter {
  color: white;
  background: #55acee;
}

.btn-login-twitter {
  color: white;
  border: 1px solid #55acee;
  background: #55acee;
}

.btn-login-twitter:hover {
  border: 1px solid #55acee;
  background: #006daa;
}


.google-g {
  width: 25px;
  height: 25px;
}

